import request from '@/benyun/utils/request'
//发货订单
export function jstOrderList(params:any){
	return request({
		url: '/omsOrder/dswDeliveryOrder/page',
		params:params,
		method: 'GET'
	})
}

//拉取聚水潭店铺订单子表（商品）
export function jstOrderListProduct(params:any){
	return request({
		url: '/omsOrder/dswDeliveryOrderLine/queryByOrderId',
		params:params,
		method: 'GET'
	})
}

//入库订单
export function inStore(params:any){
	return request({
		url: '/omsOrder/dswEntryOrder/page',
		params:params,
		method: 'GET'
	})
}
//入库单商品
export function inStoreProduct(params:any){
	return request({
		url: '/omsOrder/dswEntryOrderLine/queryByOrderId',
		params:params,
		method: 'GET'
	})
}

//出库订单
export function outStore(params:any){
	return request({
		url: '/omsOrder/dswStockOut/page',
		params:params,
		method: 'GET'
	})
}
//入库单商品
export function outStoreProduct(params:any){
	return request({
		url: '/omsOrder/dswStockOutLine/queryByOrderId',
		params:params,
		method: 'GET'
	})
}

export function printHandle(data:any){
	return request({
		url: '/wms/print/waybillGet',
		method: 'GET',
    params:data
	})
}
export function d3Print(params:any,data:any){
	return request({
		url: 'http://d3.diansan.com/app-web/open/router/rest.json',
		method: 'POST',
    params:params,
		data: data
	})
}

export function waybillPrintData(data:any){
	return request({
		url: '/wms/print/waybillPrintData',
		method: 'GET',
    params:data
	})
}

//订单发货确认接口
export function deliveryOrderConfirm(data:any){
	return request({
		url: '/wms/confirm/deliveryOrderConfirm',
		method: 'POST',
    data:data
	})
}

//入库单确认接口
export function purchaseInOrderConfirm(data:any){
	return request({
		url: '/wms/confirm/purchaseInOrderConfirm',
		method: 'POST',
    data:data
	})
}

//出库单确认接口
export function purchaseOutConfirm(data:any){
	return request({
		url: '/wms/confirm/purchaseOutConfirm',
		method: 'POST',
    data:data
	})
}